@@ -189,6 +189,36 @@ class U3ID:
 
         return self.int == other.int
 
+    def __lt__(self, other):
+        if type(other) != U3ID:
+            raise TypeError()
+
+        return self.int < other.int
+
+    def __le__(self, other):
+        if type(other) != U3ID:
+            raise TypeError()
+
+        return self.int <= other.int
+
+    def __ne__(self, other):
+        if type(other) != U3ID:
+            return True
+
+        return self.int != other.int
+
+    def __gt__(self, other):
+        if type(other) != U3ID:
+            raise TypeError()
+
+        return self.int > other.int
+
+    def __ge__(self, other):
+        if type(other) != U3ID:
+            raise TypeError()
+
+        return self.int >= other.int
+
 
 if __name__ == "__main__":
     test_class = U3IDFactory(
@@ -197,27 +227,14 @@ if __name__ == "__main__":
         total_length_bits = 128,
     )
 
-    integer_time_part = 100
-    decimal_time_part_nanoseconds = 999999999
-    chaotic_part_seed = "this is a test"
-
-    u3id = test_class.generate(chaotic_part_seed='this is a test')
     u3id = test_class.generate()
+    u3id_2 = test_class.generate()
+
+    print(u3id < u3id_2)
+    print(u3id <= u3id_2)
+    print(u3id == u3id_2)
+    print(u3id > u3id_2)
+    print(u3id >= u3id_2)
 
-    u3id = test_class.generate(
-        integer_time_part=integer_time_part,
-        decimal_time_part_nanoseconds=decimal_time_part_nanoseconds,
-        chaotic_part_seed=chaotic_part_seed
-    )
-
-    u3id_bytes = u3id.bytes
-    bits = ""
-    for i in range(len(u3id_bytes) - 1):
-        byte = u3id_bytes[i]
-        bits += f'{byte:0>8b}'
-    print("py:")
-    print(bits)
-
-    print(u3id)
 
 
